@@ -1,3 +1,5 @@
+"""MsgAuth module data types."""
+
 from __future__ import annotations
 
 import attr
@@ -15,6 +17,8 @@ __all__ = [
 
 
 class Authorization(BaseTerraData):
+    """Base class for authorization types."""
+
     @staticmethod
     def from_data(data: dict) -> Authorization:
         from terra_sdk.util.parse_authorization import parse_authorization
@@ -24,7 +28,15 @@ class Authorization(BaseTerraData):
 
 @attr.s
 class SendAuthorization(Authorization):
+    """Type of :class:`Authorization` for :class:`MsgSend<terra_sdk.core.bank.msgs.MsgSend>`,
+    which can be parameterized by setting a ``spend_limit`` allowance for the grantee.
+
+    Args:
+        spend_limit (Coins.Input): coins representing allowance of grant
+    """
+
     type = "msgauth/SendAuthorization"
+    """"""
 
     spend_limit: Coins = attr.ib(converter=Coins)
 
@@ -36,7 +48,13 @@ class SendAuthorization(Authorization):
 
 @attr.s
 class GenericAuthorization(Authorization):
+    """Generic type of :class:`Authorization`, specifying the type of message to allow.
+
+    Args:
+        grant_msg_type: type of message allowed by authorization"""
+
     type = "msgauth/GenericAuthorization"
+    """"""
 
     grant_msg_type: str = attr.ib()
 
@@ -48,9 +66,13 @@ class GenericAuthorization(Authorization):
 
 @attr.s
 class AuthorizationGrant(JSONSerializable):
+    """Contains information about an existing granted authorization between two users."""
 
     authorization: Authorization = attr.ib()
+    """Grant authorization details."""
+
     expiration: str = attr.ib()
+    """Grant expiration."""
 
     @classmethod
     def from_data(cls, data: dict) -> AuthorizationGrant:
